summaryrefslogtreecommitdiffstats
path: root/kstyles/keramik/keramik.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstyles/keramik/keramik.cpp')
-rw-r--r--kstyles/keramik/keramik.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kstyles/keramik/keramik.cpp b/kstyles/keramik/keramik.cpp
index 7105d81c5..591a5aae3 100644
--- a/kstyles/keramik/keramik.cpp
+++ b/kstyles/keramik/keramik.cpp
@@ -1357,7 +1357,7 @@ void KeramikStyle::drawKStylePrimitive( KStylePrimitive kpe,
bool KeramikStyle::isFormWidget(const TQStyleControlElementData &ceData, const ControlElementFlags elementFlags, const TQWidget* widget) const
{
if (widget) {
//Form widgets are in the KHTMLView, but that has 2 further inner levels
//of widgets - QClipperWidget, and outside of that, QViewportWidget
TQWidget* potentialClipPort = widget->parentWidget();
if ((ceData.parentWidgetData.widgetObjectTypes.isEmpty()) && (ceData.parentWidgetFlags & CEF_IsTopLevel)) {
@@ -1369,9 +1369,9 @@ bool KeramikStyle::isFormWidget(const TQStyleControlElementData &ceData, const C
qstrcmp(potentialViewPort->name(), "qt_viewport") )
return false;
- TQWidget* potentialKHTML = potentialViewPort->parentWidget();
- if (!potentialKHTML || potentialKHTML->isTopLevel() ||
- qstrcmp(potentialKHTML->className(), "KHTMLView") )
+ TQWidget* potentialTDEHTML = potentialViewPort->parentWidget();
+ if (!potentialTDEHTML || potentialTDEHTML->isTopLevel() ||
+ qstrcmp(potentialTDEHTML->className(), "TDEHTMLView") )
return false;
@@ -1357,7 +1357,7 @@ void KeramikStyle::drawKStylePrimitive( KStylePrimitive kpe,
{
if (widget) {
- //Form widgets are in the KHTMLView, but that has 2 further inner levels
+ //Form widgets are in the TDEHTMLView, but that has 2 further inner levels
//of widgets - QClipperWidget, and outside of that, QViewportWidget
TQWidget* potentialClipPort = widget->parentWidget();